summaryrefslogtreecommitdiff
path: root/utils
diff options
context:
space:
mode:
Diffstat (limited to 'utils')
-rwxr-xr-xutils/lib_sxng_static.sh3
-rwxr-xr-xutils/lib_sxng_test.sh7
-rwxr-xr-xutils/lib_sxng_themes.sh59
3 files changed, 49 insertions, 20 deletions
diff --git a/utils/lib_sxng_test.sh b/utils/lib_sxng_test.sh
index 9ac71aeeb..895a338fa 100755
--- a/utils/lib_sxng_test.sh
+++ b/utils/lib_sxng_test.sh
@@ -89,7 +89,6 @@ test.robot() {
dump_return $?
}
-
test.rst() {
build_msg TEST "[reST markup] ${RST_FILES[*]}"
@@ -98,6 +97,12 @@ test.rst() {
done
}
+test.themes() {
+ build_msg TEST 'SearXNG themes'
+ themes.test
+ dump_return $?
+}
+
test.pybabel() {
TEST_BABEL_FOLDER="build/test/pybabel"
build_msg TEST "[extract messages] pybabel"
diff --git a/utils/lib_sxng_themes.sh b/utils/lib_sxng_themes.sh
index a276dd8c5..95d38ae8d 100755
--- a/utils/lib_sxng_themes.sh
+++ b/utils/lib_sxng_themes.sh
@@ -7,21 +7,41 @@ declare _creset
themes.help(){
cat <<EOF
themes.:
- all : build all themes
- live : to get live builds of CSS & JS use 'LIVE_THEME=simple make run'
- simple.: build simple theme
- test : test simple theme
+ all : test & build all themes
+ test : test all themes
+ fix : fix JS & CSS (LESS)
+ live : to get live builds of CSS & JS use: LIVE_THEME=simple make run
+ simple.: test & build simple theme ..
pygments: build pygment's LESS files for simple theme
+ test : test simple theme
+ fix : fix JS & CSS (LESS) of the simple theme
EOF
}
themes.all() {
( set -e
+ node.env
themes.simple
)
dump_return $?
}
+themes.fix() {
+ ( set -e
+ node.env
+ themes.simple.fix
+ )
+ dump_return $?
+}
+
+themes.test() {
+ ( set -e
+ node.env
+ themes.simple.test
+ )
+ dump_return $?
+}
+
themes.live() {
local LIVE_THEME="${LIVE_THEME:-${1}}"
case "${LIVE_THEME}" in
@@ -29,30 +49,30 @@ themes.live() {
theme="searx/static/themes/${LIVE_THEME}"
;;
'')
- die_caller 42 "missing theme argument"
+ die 42 "missing theme argument"
;;
*)
- die_caller 42 "unknown theme '${LIVE_THEME}' // [simple]'"
+ die 42 "unknown theme '${LIVE_THEME}' // [simple]'"
;;
esac
- build_msg GRUNT "theme: $1 (live build)"
- nodejs.ensure
+ build_msg SIMPLE "theme: $1 (live build)"
+ node.env
+ themes.simple.pygments
cd "${theme}"
{
- npm install
npm run watch
- } 2>&1 \
- | prefix_stdout "${_Blue}THEME ${1} ${_creset} " \
- | grep -E --ignore-case --color 'error[s]?[:]? |warning[s]?[:]? |'
+ } # 2>&1 \
+ # | prefix_stdout "${_Blue}THEME ${1} ${_creset} " \
+ # | grep -E --ignore-case --color 'error[s]?[:]? |warning[s]?[:]? |'
}
themes.simple() {
( set -e
- node.env
themes.simple.pygments
+ build_msg SIMPLE "theme: run build"
+ # "run build" includes tests from eslint and stylelint
+ npm --prefix searx/static/themes/simple run build
)
- build_msg GRUNT "theme: simple"
- npm --prefix searx/static/themes/simple run build
dump_return $?
}
@@ -67,11 +87,14 @@ themes.simple.pygments() {
return 0
}
+themes.simple.fix() {
+ build_msg SIMPLE "theme: fix"
+ npm --prefix searx/static/themes/simple run fix
+ dump_return $?
+}
themes.simple.test() {
- build_msg TEST "theme: simple"
- node.env
- npm --prefix searx/static/themes/simple install
+ build_msg SIMPLE "theme: run test"
npm --prefix searx/static/themes/simple run test
dump_return $?
}
diff --git a/utils/lib_sxng_static.sh b/utils/lib_sxng_static.sh
index 2f074b91e..d991d4b89 100755
--- a/utils/lib_sxng_static.sh
+++ b/utils/lib_sxng_static.sh
@@ -100,7 +100,8 @@ static.build.commit() {
static.build.drop &>/dev/null
( set -e
- # build the themes
+ # fix & build the themes
+ themes.fix
themes.all
# add build files